@@ -1,8 +1,8 @@
 require 'rubygems'
-require 'test/unit'
+require 'minitest/autorun'
 require 'shoulda'
 require 'mocha'
 require File.dirname(__FILE__)+'/../lib/packable'
 
-class Test::Unit::TestCase
-end
\ No newline at end of file
+class Minitest::Test
+end
